<template>
	<div class="app-container">
		<div class="search_form">
			<div>
				<span class="search_title">客户名称：</span>
				<el-input
					v-model="searchForm.customerName"
					style="width: 240px"
					placeholder="请输入"
					@change="handleQuery"
					clearable
					prefix-icon="Search"
				/>
				<span class="search_title ml10">项目名称：</span>
				<el-input
					v-model="searchForm.customerName"
					style="width: 240px"
					placeholder="请输入"
					@change="handleQuery"
					clearable
					prefix-icon="Search"
				/>
				<span class="search_title ml10">录入日期：</span>
				<el-date-picker v-model="searchForm.entryDate" value-format="YYYY-MM-DD" format="YYYY-MM-DD" type="daterange"
												placeholder="请选择" clearable @change="changeDaterange" />
				<el-button type="primary" @click="handleQuery" style="margin-left: 10px"
				>搜索</el-button
				>
			</div>
			<div>
				<el-button type="primary" @click="openForm('add')">生产派工</el-button>
			</div>
		</div>
		<div class="table_list">
			<PIMTable
				rowKey="id"
				:column="tableColumn"
				:tableData="tableData"
				:page="page"
				:isSelection="true"
				@selection-change="handleSelectionChange"
				:tableLoading="tableLoading"
				@pagination="pagination"
				:total="page.total"
			></PIMTable>
		</div>
		<form-dia ref="formDia" @close="handleQuery"></form-dia>
	</div>
</template>

<script setup>
import {onMounted, ref} from "vue";
import FormDia from "@/views/productionManagement/productionDispatching/components/formDia.vue";
import {staffJoinDel, staffJoinListPage} from "@/api/personnelManagement/onboarding.js";
import {ElMessageBox} from "element-plus";
import dayjs from "dayjs";

const data = reactive({
	searchForm: {
		staffName: "",
		entryDate: [
			dayjs().format("YYYY-MM-DD"),
			dayjs().add(1, "day").format("YYYY-MM-DD"),
		], // 录入日期
		entryDateStart: dayjs().format("YYYY-MM-DD"),
		entryDateEnd: dayjs().add(1, "day").format("YYYY-MM-DD"),
	},
});
const { searchForm } = toRefs(data);
const tableColumn = ref([
	{
		label: "录入日期",
		prop: "staffNo",
	},
	{
		label: "合同号",
		prop: "staffName",
	},
	{
		label: "客户合同号",
		prop: "addressPhone",
		width: 250,
	},
	{
		label: "客户名称",
		prop: "contactPerson",
	},
	{
		label: "项目名称",
		prop: "contactPhone",
		width:150
	},
	{
		label: "产品大类",
		prop: "basicBankAccount",
		width: 220,
	},
	{
		label: "规格型号",
		prop: "bankAccount",
		width: 220,
	},
	{
		label: "单位",
		prop: "bankCode",
		width:220
	},
	{
		label: "数量",
		prop: "maintainer",
	},
	{
		label: "排产数量",
		prop: "maintenanceTime",
		width: 100,
	},
	{
		label: "待排数量",
		prop: "maintenanceTime",
		width: 100,
	},
]);
const tableData = ref([]);
const selectedRows = ref([]);
const tableLoading = ref(false);
const page = reactive({
	current: 1,
	size: 100,
	total: 0,
});
const formDia = ref()
const { proxy } = getCurrentInstance()

// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
	page.current = 1;
	getList();
};
const changeDaterange = (value) => {
	if (value) {
		searchForm.entryDateStart = dayjs(value[0]).format("YYYY-MM-DD");
		searchForm.entryDateEnd = dayjs(value[1]).format("YYYY-MM-DD");
	} else {
		searchForm.entryDateStart = undefined;
		searchForm.entryDateEnd = undefined;
	}
	handleQuery();
};
const pagination = (obj) => {
	page.current = obj.page;
	page.size = obj.limit;
	getList();
};
const getList = () => {
	tableLoading.value = true;
	staffJoinListPage({...page, ...searchForm.value}).then(res => {
		tableLoading.value = false;
		tableData.value = res.data.records
		page.total = res.data.total;
	}).catch(err => {
		tableLoading.value = false;
	})
};
// 表格选择数据
const handleSelectionChange = (selection) => {
	selectedRows.value = selection;
};

// 打开弹框
const openForm = (type, row) => {
	if (selectedRows.value.length !== 1) {
		proxy.$message.error("请选择一条数据");
		return;
	}
	if (selectedRows.value[0].unPaymentAmountTotal == 0) {
		proxy.$message.warning("无需再付款");
		return;
	}
	nextTick(() => {
		formDia.value?.openDialog(type, row)
	})
};

// 删除
const handleDelete = () => {
	let ids = [];
	if (selectedRows.value.length > 0) {
		ids = selectedRows.value.map((item) => item.id);
	} else {
		proxy.$modal.msgWarning("请选择数据");
		return;
	}
	ElMessageBox.confirm("选中的内容将被删除，是否确认删除？", "导出", {
		confirmButtonText: "确认",
		cancelButtonText: "取消",
		type: "warning",
	})
		.then(() => {
			staffJoinDel(ids).then((res) => {
				proxy.$modal.msgSuccess("删除成功");
				getList();
			});
		})
		.catch(() => {
			proxy.$modal.msg("已取消");
		});
};
// 导出
const handleOut = () => {
	ElMessageBox.confirm("选中的内容将被导出，是否确认导出？", "导出", {
		confirmButtonText: "确认",
		cancelButtonText: "取消",
		type: "warning",
	})
		.then(() => {
			proxy.download("/staff/staffJoinLeaveRecord/export", {staffState: 1}, "人员入职.xlsx");
		})
		.catch(() => {
			proxy.$modal.msg("已取消");
		});
};
onMounted(() => {
	getList();
});
</script>

<style scoped></style>
